==> Pyrogram-1.0.3-py3-none-any.whl: pyrogram/raw/types/update_user_blocked.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Union, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class UpdateUserBlocked(TLObject):  # type: ignore
    """This object is a constructor of the base type :obj:`~pyrogram.raw.base.Update`.

    Details:
        - Layer: ``117``
        - ID: ``0x80ece81a``

    Parameters:
        user_id: ``int`` ``32-bit``
        blocked: ``bool``
    """

    __slots__: List[str] = ["user_id", "blocked"]

    ID = 0x80ece81a
    QUALNAME = "pyrogram.raw.types.UpdateUserBlocked"

    def __init__(self, *, user_id: int, blocked: bool) -> None:
        self.user_id = user_id  # int
        self.blocked = blocked  # Bool

    @staticmethod
    def read(data: BytesIO, *args: Any) -> "UpdateUserBlocked":
        # No flags
        
        user_id = Int.read(data)
        
        blocked = Bool.read(data)
        
        return UpdateUserBlocked(user_id=user_id, blocked=blocked)

    def write(self) -> bytes:
        data = BytesIO()
        data.write(Int(self.ID, False))

        # No flags
        
        data.write(Int(self.user_id))
        
        data.write(Bool(self.blocked))
        
        return data.getvalue()

==> Pyrogram-1.0.7-py3-none-any.whl: pyrogram/raw/types/update_user_blocked.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Union, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class UpdateUserBlocked(TLObject):  # type: ignore
    """This object is a constructor of the base type :obj:`~pyrogram.raw.base.Update`.

    Details:
        - Layer: ``117``
        - ID: ``0x80ece81a``

    Parameters:
        user_id: ``int`` ``32-bit``
        blocked: ``bool``
    """

    __slots__: List[str] = ["user_id", "blocked"]

    ID = 0x80ece81a
    QUALNAME = "types.UpdateUserBlocked"

    def __init__(self, *, user_id: int, blocked: bool) -> None:
        self.user_id = user_id  # int
        self.blocked = blocked  # Bool

    @staticmethod
    def read(data: BytesIO, *args: Any) -> "UpdateUserBlocked":
        # No flags
        
        user_id = Int.read(data)
        
        blocked = Bool.read(data)
        
        return UpdateUserBlocked(user_id=user_id, blocked=blocked)

    def write(self) -> bytes:
        data = BytesIO()
        data.write(Int(self.ID, False))

        # No flags
        
        data.write(Int(self.user_id))
        
        data.write(Bool(self.blocked))
        
        return data.getvalue()
